# Cinnamon Tensorflow package

The tensorflow package offers ``Component`` and related ``Configuration`` that rely on the Tensorflow library.

Thus, ``cinnamon-tf`` mainly provides ``Model``, ``Callback`` and ``Helper`` implementations.

## Components and Configurations

The tensorflow package defines the following ``Component`` and ``Configuration``

- Neural networks: a high-level implementation to build your tensorflow-based neural models.
- Callbacks (e.g., early stopping)
- Framework helpers for tensorflow/cuda deterministic behaviour

## Install

pip

      pip install cinnamon-tf

git

      git clone https://github.com/federicoruggeri/cinnamon_tf

## Contribute

Want to contribute with new ``Component`` and ``Configuration``?

Feel free to submit a merge request! 

Cinnamon is meant to be a community project :)

## Contact

Don't hesitate to contact:
- Federico Ruggeri @ [federico.ruggeri6@unibo.it](mailto:federico.ruggeri6@unibo.it)

for questions/doubts/issues!